import { Center, Flex, Spinner, Text } from "@chakra-ui/react";
import AppGuard from "@lib/Guards";
import { useAuth } from "@src/ctx/AuthContext";
import useContentGuard, { GuardedContent } from "@src/util/guards";
import { Links, rootLink } from "@src/util/links";
import { useEffect, useState } from "react";
import { Navigate } from "react-router-dom";

export default function AutoRedirect() {
  const manageProjects = useContentGuard(AppGuard.ManageProjects);
  const { auth, initialized, loading } = useAuth();
  if (!initialized || loading) return <RedirectLoader />;
  if (!auth) return <Navigate to={rootLink(Links.Authenticate)} />;
  if (manageProjects) return <Navigate to={rootLink(Links.ProjectView)} />;
  return <Navigate to={rootLink(Links.Authorized)} />;
}

export function RedirectLoader() {
  const [visible, setVisible] = useState<boolean>(false);
  useEffect(() => {
    setTimeout(() => setVisible(true), 1500);
  }, []);
  return (
    <Center m="auto" h="100vh">
      <Flex flexWrap="wrap">
        <GuardedContent guard={visible}>
          <Spinner size="xl" color="primary" m="auto" />
          <Text w="100%" textAlign="center" mt="1.5rem">
            Loading
          </Text>
        </GuardedContent>
      </Flex>
    </Center>
  );
}
